@@ -1,5 +1,7 @@
 """
-Main interface for sso-oidc service client
+Type annotations for sso-oidc service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
 
 Usage::
 
@@ -49,7 +51,8 @@ class Exceptions:
 
 class SSOOIDCClient:
     """
-    [SSOOIDC.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
     """
 
     meta: ClientMeta
@@ -57,7 +60,8 @@ class SSOOIDCClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#can-paginate)
         """
 
     def create_token(
@@ -72,7 +76,8 @@ class SSOOIDCClient:
         redirectUri: str = None,
     ) -> CreateTokenResponseTypeDef:
         """
-        [Client.create_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#create-token)
         """
 
     def generate_presigned_url(
@@ -83,19 +88,22 @@ class SSOOIDCClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#generate-presigned-url)
         """
 
     def register_client(
         self, clientName: str, clientType: str, scopes: List[str] = None
     ) -> RegisterClientResponseTypeDef:
         """
-        [Client.register_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#register-client)
         """
 
     def start_device_authorization(
         self, clientId: str, clientSecret: str, startUrl: str
     ) -> StartDeviceAuthorizationResponseTypeDef:
         """
-        [Client.start_device_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#start-device-authorization)
         """
